==> api-0.10.0-sources.jar: eu/fispace/api/ag/CropFieldAdviceRequestMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2014.08.13 a las 11:35:06 PM CEST 
//


package eu.fispace.api.ag;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import eu.limetri.platform.api.RequestMessage;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.limetri.eu/schemas/platform}RequestMessage">
 *       &lt;sequence>
 *         &lt;element name="adviceRequest" type="{http://www.fispace.eu/domain/ag}CropFieldAdviceRequest"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "adviceRequest"
})
@XmlRootElement(name = "CropFieldAdviceRequestMessage", namespace = "")
public class CropFieldAdviceRequestMessage
    extends RequestMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected CropFieldAdviceRequest adviceRequest;

    /**
     * Obtiene el valor de la propiedad adviceRequest.
     * 
     * @return
     *     possible object is
     *     {@link CropFieldAdviceRequest }
     *     
     */
    public CropFieldAdviceRequest getAdviceRequest() {
        return adviceRequest;
    }

    /**
     * Define el valor de la propiedad adviceRequest.
     * 
     * @param value
     *     allowed object is
     *     {@link CropFieldAdviceRequest }
     *     
     */
    public void setAdviceRequest(CropFieldAdviceRequest value) {
        this.adviceRequest = value;
    }

    public boolean isSetAdviceRequest() {
        return (this.adviceRequest!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            CropFieldAdviceRequest theAdviceRequest;
            theAdviceRequest = this.getAdviceRequest();
            strategy.appendField(locator, this, "adviceRequest", buffer, theAdviceRequest);
        }
        return buffer;
    }

    public CropFieldAdviceRequestMessage withAdviceRequest(CropFieldAdviceRequest value) {
        setAdviceRequest(value);
        return this;
    }

}

==> api-0.14.0-sources.jar: eu/fispace/api/ag/CropFieldAdviceRequestMessage.java <==
//
// Este archivo ha sido generado por la arquitectura JavaTM para la implantación de la referencia de enlace (JAXB) XML v2.2.7 
// Visite <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Todas las modificaciones realizadas en este archivo se perderán si se vuelve a compilar el esquema de origen. 
// Generado el: 2015.02.03 a las 12:57:50 PM CET 
//


package eu.fispace.api.ag;

import java.io.Serializable;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import eu.limetri.ygg.api.RequestMessage;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Clase Java para anonymous complex type.
 * 
 * <p>El siguiente fragmento de esquema especifica el contenido que se espera que haya en esta clase.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.limetri.eu/schemas/ygg}RequestMessage">
 *       &lt;sequence>
 *         &lt;element name="adviceRequest" type="{http://www.fispace.eu/domain/ag}CropFieldAdviceRequest"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "adviceRequest"
})
@XmlRootElement(name = "CropFieldAdviceRequestMessage")
public class CropFieldAdviceRequestMessage
    extends RequestMessage
    implements Serializable, ToString
{

    @XmlElement(required = true)
    protected CropFieldAdviceRequest adviceRequest;

    /**
     * Obtiene el valor de la propiedad adviceRequest.
     * 
     * @return
     *     possible object is
     *     {@link CropFieldAdviceRequest }
     *     
     */
    public CropFieldAdviceRequest getAdviceRequest() {
        return adviceRequest;
    }

    /**
     * Define el valor de la propiedad adviceRequest.
     * 
     * @param value
     *     allowed object is
     *     {@link CropFieldAdviceRequest }
     *     
     */
    public void setAdviceRequest(CropFieldAdviceRequest value) {
        this.adviceRequest = value;
    }

    public boolean isSetAdviceRequest() {
        return (this.adviceRequest!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            CropFieldAdviceRequest theAdviceRequest;
            theAdviceRequest = this.getAdviceRequest();
            strategy.appendField(locator, this, "adviceRequest", buffer, theAdviceRequest);
        }
        return buffer;
    }

    public CropFieldAdviceRequestMessage withAdviceRequest(CropFieldAdviceRequest value) {
        setAdviceRequest(value);
        return this;
    }

}
